==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/com.openexchange.server/src/com/openexchange/groupware/update/tasks/objectpermission/ObjectPermissionCreateTableService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.update.tasks.objectpermission;

import com.openexchange.database.AbstractCreateTableImpl;

/**
 * {@link ObjectPermissionCreateTableService}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class ObjectPermissionCreateTableService extends AbstractCreateTableImpl {

    public ObjectPermissionCreateTableService() {
        super();
    }

    @Override
    public String[] getCreateStatements() {
        return new String[] {

            ("CREATE TABLE `object_permission` ("
            + "`cid` INT4 UNSIGNED NOT NULL,"
            + "`permission_id` INT4 UNSIGNED NOT NULL,"
            + "`module` INT4 UNSIGNED NOT NULL,"
            + "`folder_id` INT4 UNSIGNED NOT NULL,"
            + "`object_id` INT4 UNSIGNED NOT NULL,"
            + "`created_by` INT4 UNSIGNED NOT NULL,"
            + "`shared_by` INT4 UNSIGNED NOT NULL,"
            + "`bits` INT4 UNSIGNED NOT NULL,"
            + "`last_modified` BIGINT(64) NOT NULL,"
            + "`group_flag` TINYINT UNSIGNED NOT NULL,"
            + "PRIMARY KEY (`cid`,`permission_id`,`module`,`folder_id`,`object_id`),"
            + "INDEX `created_by_index` (`cid`, `created_by`),"
            + "INDEX `shared_by_index` (`cid`, `shared_by`),"
            + "INDEX `last_modified_index` (`cid`, `permission_id`, `module`, `last_modified`)"
            + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci"),

            ("CREATE TABLE `del_object_permission` ("
            + "`cid` INT4 UNSIGNED NOT NULL,"
            + "`permission_id` INT4 UNSIGNED NOT NULL,"
            + "`module` INT4 UNSIGNED NOT NULL,"
            + "`folder_id` INT4 UNSIGNED NOT NULL,"
            + "`object_id` INT4 UNSIGNED NOT NULL,"
            + "`created_by` INT4 UNSIGNED NOT NULL,"
            + "`shared_by` INT4 UNSIGNED NOT NULL,"
            + "`bits` INT4 UNSIGNED NOT NULL,"
            + "`last_modified` BIGINT(64) NOT NULL,"
            + "`group_flag` TINYINT UNSIGNED NOT NULL,"
            + "PRIMARY KEY (`cid`,`permission_id`,`module`,`folder_id`,`object_id`),"
            + "INDEX `created_by_index` (`cid`, `created_by`),"
            + "INDEX `shared_by_index` (`cid`, `shared_by`),"
            + "INDEX `last_modified_index` (`cid`, `permission_id`, `module`, `last_modified`)"
            + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci")
        };
    }

    @Override
    public String[] requiredTables() {
        return new String[] { "user" };
    }

    @Override
    public String[] tablesToCreate() {
        return new String[] { "object_permission", "del_object_permission" };
    }

}

==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.server/src/com/openexchange/groupware/update/tasks/objectpermission/ObjectPermissionCreateTableService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.update.tasks.objectpermission;

import com.openexchange.database.AbstractCreateTableImpl;

/**
 * {@link ObjectPermissionCreateTableService}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class ObjectPermissionCreateTableService extends AbstractCreateTableImpl {

    public ObjectPermissionCreateTableService() {
        super();
    }

    @Override
    public String[] getCreateStatements() {
        return new String[] {

            ("CREATE TABLE `object_permission` ("
            + "`cid` INT4 UNSIGNED NOT NULL,"
            + "`permission_id` INT4 UNSIGNED NOT NULL,"
            + "`module` INT4 UNSIGNED NOT NULL,"
            + "`folder_id` INT4 UNSIGNED NOT NULL,"
            + "`object_id` INT4 UNSIGNED NOT NULL,"
            + "`created_by` INT4 UNSIGNED NOT NULL,"
            + "`shared_by` INT4 UNSIGNED NOT NULL,"
            + "`bits` INT4 UNSIGNED NOT NULL,"
            + "`last_modified` BIGINT(64) NOT NULL,"
            + "`group_flag` TINYINT UNSIGNED NOT NULL,"
            + "PRIMARY KEY (`cid`,`permission_id`,`module`,`folder_id`,`object_id`),"
            + "INDEX `created_by_index` (`cid`, `created_by`),"
            + "INDEX `shared_by_index` (`cid`, `shared_by`),"
            + "INDEX `last_modified_index` (`cid`, `permission_id`, `module`, `last_modified`)"
            + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci"),

            ("CREATE TABLE `del_object_permission` ("
            + "`cid` INT4 UNSIGNED NOT NULL,"
            + "`permission_id` INT4 UNSIGNED NOT NULL,"
            + "`module` INT4 UNSIGNED NOT NULL,"
            + "`folder_id` INT4 UNSIGNED NOT NULL,"
            + "`object_id` INT4 UNSIGNED NOT NULL,"
            + "`created_by` INT4 UNSIGNED NOT NULL,"
            + "`shared_by` INT4 UNSIGNED NOT NULL,"
            + "`bits` INT4 UNSIGNED NOT NULL,"
            + "`last_modified` BIGINT(64) NOT NULL,"
            + "`group_flag` TINYINT UNSIGNED NOT NULL,"
            + "PRIMARY KEY (`cid`,`permission_id`,`module`,`folder_id`,`object_id`),"
            + "INDEX `created_by_index` (`cid`, `created_by`),"
            + "INDEX `shared_by_index` (`cid`, `shared_by`),"
            + "INDEX `last_modified_index` (`cid`, `permission_id`, `module`, `last_modified`)"
            + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci")
        };
    }

    @Override
    public String[] requiredTables() {
        return new String[] { "user" };
    }

    @Override
    public String[] tablesToCreate() {
        return new String[] { "object_permission", "del_object_permission" };
    }

}
